@@ -28,8 +28,6 @@ from tripleoclient.workflows import deployment
 from tripleoclient.workflows import parameters
 
 CONF = cfg.CONF
-logging.register_options(CONF)
-logging.setup(CONF, '')
 
 
 class UpgradePrepare(DeployOvercloud):
@@ -59,6 +57,8 @@ class UpgradePrepare(DeployOvercloud):
         return parser
 
     def take_action(self, parsed_args):
+        logging.register_options(CONF)
+        logging.setup(CONF, '')
         self.log.debug("take_action(%s)" % parsed_args)
         oooutils.ensure_run_as_normal_user()
 
@@ -204,9 +204,19 @@ class UpgradeRun(command.Command):
                                    "required before any upgrade "
                                    "operation. Use this with caution! ")
                             )
+        parser.add_argument(
+            '--ansible-forks',
+            action='store',
+            default=None,
+            type=int,
+            help=_('The number of Ansible forks to use for the'
+                   ' config-download ansible-playbook command.')
+        )
         return parser
 
     def take_action(self, parsed_args):
+        logging.register_options(CONF)
+        logging.setup(CONF, '')
         self.log.debug("take_action(%s)" % parsed_args)
         oooutils.ensure_run_as_normal_user()
 
@@ -248,7 +258,8 @@ class UpgradeRun(command.Command):
             skip_tags=parsed_args.skip_tags,
             limit_hosts=oooutils.playbook_limit_parse(
                 limit_nodes=parsed_args.limit
-            )
+            ),
+            forks=parsed_args.ansible_forks
         )
         self.log.info("Completed Overcloud Major Upgrade Run.")
 
